@@ -26,10 +26,10 @@ try:
 except ImportError:
 	import techrepublic
 
-try:
-	from TechParser import readwrite
-except ImportError:
-	import readwrite
+#try:
+#	from TechParser import readwrite
+#except ImportError:
+#	import readwrite
 
 try:
 	from TechParser import smashingmagazine
@@ -81,6 +81,31 @@ try:
 except ImportError:
 	import codeproject
 
+try:
+	from TechParser import hackernews
+except ImportError:
+	import hackernews
+
+try:
+	from TechParser import mashable
+except ImportError:
+	import mashable
+
+try:
+	from TechParser import maketecheasier
+except ImportError:
+	import maketecheasier
+
+try:
+	from TechParser import digg
+except ImportError:
+	import digg
+
+try:
+	from TechParser import wired
+except ImportError:
+	import wired
+
 sites_to_parse = {
 		"Habrahabr": { # habrahabr.ru
 			"module": habrahabr,
@@ -112,10 +137,10 @@ sites_to_parse = {
 			"kwargs": {}
 		},
 		
-		# Doesn't work anymore
+		# Works only with Selenium (opens REAL browser)
 		#"Read/Write Web": { # readwrite.com
 		#	"module": readwrite,
-		#	"kwargs": {}
+		#	"kwargs": {"browser": "firefox"}
 		#},
 		
 		"Tech Republic": { # techrepublic.com
@@ -161,6 +186,31 @@ sites_to_parse = {
 		"Code Project": { # www.codeproject.com
 			"module": codeproject,
 			"kwargs": {"start_page": 1, "end_page": 1}
+		},
+		
+		"Hacker News": { # news.ycombinator.com/newest
+			"module": hackernews,
+			"kwargs": {"start_page": 1, "end_page": 5}
+		},
+		
+		"Mashable": { # mashable.com
+			"module": mashable,
+			"kwargs": {}
+		},
+		
+		"Make Tech Easier": { # www.maketecheasier.com
+			"module": maketecheasier,
+			"kwargs": {}
+		},
+		
+		"Digg": { # digg.com
+			"module": digg,
+			"kwargs": {}
+		},
+		
+		"Wired": { # www.wired.com
+			"module": wired,
+			"kwargs": {}
 		}
 	}
 
